==> haskell-time-locale-compat-0.1.1.5-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-locale-compat
version:              0.1.1.5
visibility:           public
id:                   time-locale-compat-0.1.1.5-HOIeHz8A3IdD2UbO8b27LU
key:                  time-locale-compat-0.1.1.5-HOIeHz8A3IdD2UbO8b27LU
license:              BSD-3-Clause
copyright:            Copyright (c) 2014-2018 Kei Hibino
maintainer:           ex8k.hibino@gmail.com
author:               Kei Hibino
homepage:             https://github.com/khibino/haskell-time-locale-compat
synopsis:             Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.

category:             System
abi:                  79a082bfc25f3b8c8877d633e802be39
exposed:              True
exposed-modules:      Data.Time.Locale.Compat
import-dirs:          /usr/lib/ghc-9.0.1/site-local/time-locale-compat-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/time-locale-compat-0.1.1.5

hs-libraries:         HStime-locale-compat-0.1.1.5-HOIeHz8A3IdD2UbO8b27LU
depends:              base-4.15.0.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock

haddock-html:         /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-locale-compat-0.1.1.5-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-locale-compat
version:              0.1.1.5
visibility:           public
id:                   time-locale-compat-0.1.1.5-1snbmhWP0619voIlJd9qOd
key:                  time-locale-compat-0.1.1.5-1snbmhWP0619voIlJd9qOd
license:              BSD-3-Clause
copyright:            Copyright (c) 2014-2018 Kei Hibino
maintainer:           ex8k.hibino@gmail.com
author:               Kei Hibino
homepage:             https://github.com/khibino/haskell-time-locale-compat
synopsis:             Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.

category:             System
abi:                  bb5d23770c652a1ef50b64bcafcdfb79
exposed:              True
exposed-modules:      Data.Time.Locale.Compat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/time-locale-compat-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/time-locale-compat-0.1.1.5

hs-libraries:         HStime-locale-compat-0.1.1.5-1snbmhWP0619voIlJd9qOd
depends:              base-4.15.1.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock

haddock-html:         /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
